@@ -82,9 +82,9 @@ test_that("Shiny Render", {
 
 test_that("Shiny Examples", {
     expect_error(cxShinyExample("badexample"),
-                 regexp = "Valid examples are: 'example1', 'example2', 'example3'")
+                 regexp = "Valid examples are: 'example1', 'example2', 'example3', 'example4'")
     expect_message(cxShinyExample(NULL),
-                 regexp = "Valid examples are: 'example1', 'example2', 'example3'")
+                 regexp = "Valid examples are: 'example1', 'example2', 'example3', 'example4'")
 })
 
 
